Submitted By:            Douglas R. Reno <renodr at linuxfromscratch dot org>
Date:                    2019-07-05
Initial Package Version: 1.4.0
Upstream Status:         Uncertain
Description:             Fixes CVE-2014-9638 and CVE-2014-9639 in vorbis-tools.

diff -Naurp vorbis-tools-1.4.0.orig/oggenc/audio.c vorbis-tools-1.4.0/oggenc/audio.c
--- vorbis-tools-1.4.0.orig/oggenc/audio.c	2010-03-24 03:27:14.000000000 -0500
+++ vorbis-tools-1.4.0/oggenc/audio.c	2019-07-05 13:59:17.660452442 -0500
@@ -13,6 +13,7 @@
 #include <config.h>
 #endif
 
+#include <limits.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -251,6 +252,7 @@ int aiff_open(FILE *in, oe_enc_opt *opt,
     aiff_fmt format;
     aifffile *aiff = malloc(sizeof(aifffile));
     int i;
+    long channels;
 
     if(buf[11]=='C')
         aifc=1;
@@ -277,11 +279,16 @@ int aiff_open(FILE *in, oe_enc_opt *opt,
         return 0;
     }
 
-    format.channels = READ_U16_BE(buffer);
+    format.channels = channels = READ_U16_BE(buffer);
     format.totalframes = READ_U32_BE(buffer+2);
     format.samplesize = READ_U16_BE(buffer+6);
     format.rate = (int)read_IEEE80(buffer+8);
 
+    if(channels <= 0L || SHRT_MAX < channels)
+    {
+       fprintf(stderr, _("Warning: Unsupported count of channels in AIFF header\n"));
+       return 0;
+    }
     aiff->bigendian = 1;
 
     if(aifc)
@@ -412,6 +419,7 @@ int wav_open(FILE *in, oe_enc_opt *opt,
     wav_fmt format;
     wavfile *wav = malloc(sizeof(wavfile));
     int i;
+    long channels;
 
     /* Ok. At this point, we know we have a WAV file. Now we have to detect
      * whether we support the subtype, and we have to find the actual data
@@ -449,12 +457,18 @@ int wav_open(FILE *in, oe_enc_opt *opt,
     }
 
     format.format =      READ_U16_LE(buf);
-    format.channels =    READ_U16_LE(buf+2);
+    format.channels = channels = READ_U16_LE(buf+2);
     format.samplerate =  READ_U32_LE(buf+4);
     format.bytespersec = READ_U32_LE(buf+8);
     format.align =       READ_U16_LE(buf+12);
     format.samplesize =  READ_U16_LE(buf+14);
 
+    if(channels <= 0L || SHRT_MAX < channels)
+    {
+       fprintf(stderr, _("Warning: Unsupported count of channels in WAV header\n"));
+       return 0;
+    }
+
     if(format.format == -2) /* WAVE_FORMAT_EXTENSIBLE */
     {
       if(len<40)
